# -*- coding: utf-8 -*-
import sys

from werkzeug.serving import run_simple
from werkzeug.wsgi import DispatcherMiddleware
from api_pagador.urls import registrar
from api_pagador.app import app_pagador

sys.path.append('./')
registrar()

if __name__ == "__main__":
    from api_pagador import settings
    parent_app = DispatcherMiddleware(app_pagador, {})
    run_simple(settings.HOST, settings.PORT, parent_app)
